@@ -94,16 +94,17 @@ following methods control this behaviour:
 When properly installed, the on-disk layout of an app managed by esky looks
 like this:
 
-    prog.exe                 - esky bootstrapping executable
-    appname-X.Y.platform/    - specific version of the application
-        prog.exe             - executable(s) as produced by freezer module
-        library.zip          - pure-python frozen modules
-        pythonXY.dll         - python DLL
-        esky-bootstrap/      - files not yet moved into bootstrapping env
-        esky-bootstrap.txt   - list of files expected in the bootstrapping env
-        esky-lockfile.txt    - lock file to control access to in-use versions
-        ...other deps...
-    updates/                 - work area for fetching/unpacking updates
+    prog.exe                     - esky bootstrapping executable
+    appname-X.Y.platform/        - specific version of the application
+      prog.exe                   - executable(s) as produced by freezer module
+      library.zip                - pure-python frozen modules
+      pythonXY.dll               - python DLL
+      esky-files/                - esky control files
+        bootstrap/               - files not yet moved into bootstrapping env
+        bootstrap-manifest.txt   - list of files expected in bootstrap env
+        lockfile.txt             - lockfile to block removal of in-use versions
+      ...other deps...
+    updates/                     - work area for fetching/unpacking updates
 
 This is also the layout of the zipfiles produced by bdist_esky.  The 
 "appname-X.Y" directory is simply a frozen app directory with some extra
@@ -111,14 +112,14 @@ control information generated by esky.
 
 To install a new version "appname-X.Z", esky performs the following steps:
     * extract it into a temporary directory under "updates"
-    * move all bootstrapping files into "appname-X.Z.platm/esky-bootstrap"
+    * move all bootstrapping files into "appname-X.Z.platm/esky/bootstrap"
     * atomically rename it into the main directory as "appname-X.Z.platform"
-    * move contents of "appname-X.Z.platform/esky-bootstrap" into the main dir
-    * remove the "appname-X.Z.platform/esky-bootstrap" directory
+    * move contents of "appname-X.Z.platform/esky/bootstrap" into the main dir
+    * remove the "appname-X.Z.platform/esky/bootstrap" directory
 
 To uninstall an existing version "appname-X.Y", esky does the following
     * remove files used by only that version from the bootstrap env
-    * rename its "esky-bootstrap.txt" file to "esky-bootstrap-old.txt"
+    * rename its "bootstrap-manifest.txt" file to "bootstrap-manifest-old.txt"
 
 Where such facilities are provided by the operating system, this process is
 performed within a filesystem transaction. Nevertheless, the esky bootstrapping
@@ -134,8 +135,8 @@ and generally tries to tidy up in the main application directory.
 from __future__ import with_statement
 
 __ver_major__ = 0
-__ver_minor__ = 7
-__ver_patch__ = 4
+__ver_minor__ = 8
+__ver_patch__ = 0
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 __version__ = "%d.%d.%d%s" % __ver_tuple__
@@ -173,7 +174,7 @@ from esky.sudo import SudoProxy, has_root, allow_from_sudo
 from esky.util import split_app_version, join_app_version,\
                       is_version_dir, is_uninstalled_version_dir,\
                       parse_version, get_best_version, appdir_from_executable,\
-                      copy_ownership_info, lock_version_dir
+                      copy_ownership_info, lock_version_dir, ESKY_CONTROL_DIR
 
 
 
@@ -478,7 +479,7 @@ class Esky(object):
                     #  Can't prove it's safe to remove, so leave it.
                     pass
         #  If there are pending overwrites, try to do them.
-        ovrdir = os.path.join(appdir,best_version,"esky-overwrite")
+        ovrdir = os.path.join(appdir,best_version,ESKY_CONTROL_DIR,"overwrite")
         if os.path.exists(ovrdir):
             try:
                 for (dirnm,_,filenms) in os.walk(ovrdir,topdown=False):
@@ -575,12 +576,12 @@ class Esky(object):
             return False
         try:
             if os.path.isdir(fullpath):
-                #  Remove paths starting with "esky-" last, since we use
+                #  Remove paths starting with "esky" last, since we use
                 #  these to maintain state information.
                 esky_paths = []
                 success = True
                 for nm in os.listdir(fullpath):
-                    if nm.startswith("esky-"):
+                    if nm == "esky" or nm.startswith("esky-"):
                         esky_paths.append(nm)
                     else:
                         subdir = os.path.join(path,nm)
@@ -694,11 +695,13 @@ class Esky(object):
                 best_version = version
         return best_version
 
-    @allow_from_sudo(str)
-    def fetch_version(self,version):
+    def fetch_version(self,version,callback=None):
         """Fetch the specified updated version of the app."""
         if self.sudo_proxy is not None:
-            return self.sudo_proxy.fetch_version(version)
+            for status in self.sudo_proxy.fetch_version_iter(version):
+                if callback is not None:
+                    callback(status)
+            return self.version_finder.has_version(self,version)
         if self.version_finder is None:
             raise NoVersionFinderError
         #  Guard against malicious input (might be called with root privs)
@@ -708,12 +711,38 @@ class Esky(object):
         #  Get the new version using the VersionFinder
         loc = self.version_finder.has_version(self,version)
         if not loc:
-            loc = self.version_finder.fetch_version(self,version)
+            loc = self.version_finder.fetch_version(self,version,callback)
         #  Adjust permissions to match the current version
         vdir = join_app_version(self.name,self.version,self.platform)
         copy_ownership_info(os.path.join(self.appdir,vdir),loc)
         return loc
 
+    @allow_from_sudo(str,iterator=True)
+    def fetch_version_iter(self,version):
+        """Fetch specified version of the app, with iterator control flow."""
+        if self.sudo_proxy is not None:
+            for status in self.sudo_proxy.fetch_version_iter(version):
+                yield status
+            return
+        if self.version_finder is None:
+            raise NoVersionFinderError
+        #  Guard against malicious input (might be called with root privs)
+        target = join_app_version(self.name,version,self.platform)
+        target = os.path.join(self.appdir,target)
+        assert os.path.dirname(target) == self.appdir
+        #  Get the new version using the VersionFinder
+        loc = self.version_finder.has_version(self,version)
+        if not loc:
+            for status in self.version_finder.fetch_version_iter(self,version):
+                if status["status"] != "ready":
+                    yield status
+                else:
+                    loc = status["path"]
+        #  Adjust permissions to match the current version
+        vdir = join_app_version(self.name,self.version,self.platform)
+        copy_ownership_info(os.path.join(self.appdir,vdir),loc)
+        yield {"status":"ready","path":loc}
+
     @allow_from_sudo(str)
     def install_version(self,version):
         """Install the specified version of the app.
@@ -754,7 +783,7 @@ class Esky(object):
         assert os.path.dirname(target) == self.appdir
         #  Move new bootrapping environment into main app dir.
         #  Be sure to move dependencies before executables.
-        bootstrap = os.path.join(target,"esky-bootstrap")
+        bootstrap = os.path.join(target,ESKY_CONTROL_DIR,"bootstrap")
         for nm in self._version_manifest(vdir):
             bssrc = os.path.join(bootstrap,nm)
             bsdst = os.path.join(self.appdir,nm)
@@ -766,7 +795,7 @@ class Esky(object):
                     if not files_differ(bssrc,bsdst):
                         trn.remove(bssrc)
                     elif is_safe_to_overwrite(bssrc,bsdst):
-                        ovrdir = os.path.join(target,"esky-overwrite")
+                        ovrdir = os.path.join(target,ESKY_CONTROL_DIR,"overwrite")
                         if not os.path.exists(ovrdir):
                             os.mkdir(ovrdir)
                         trn.move(bssrc,os.path.join(ovrdir,nm))
@@ -789,9 +818,15 @@ class Esky(object):
         target = os.path.join(self.appdir,target_name)
         #  Guard against malicious input (might be called with root privs)
         assert os.path.dirname(target) == self.appdir
-        lockfile = os.path.join(target,"esky-lockfile.txt")
-        bsfile = os.path.join(target,"esky-bootstrap.txt")
-        bsfile_old = os.path.join(target,"esky-bootstrap-old.txt")
+        # TODO: remove compatability hooks
+        lockfile = os.path.join(target,ESKY_CONTROL_DIR,"lockfile.txt")
+        if not os.path.exists(lockfile):
+            lockfile = os.path.join(target,"esky-lockfile.txt")
+        bsfile = os.path.join(target,ESKY_CONTROL_DIR,"bootstrap-manifest.txt")
+        bsfile_old = os.path.join(target,ESKY_CONTROL_DIR,"bootstrap-manifest-old.txt")
+        if not os.path.exists(bsfile):
+            bsfile = os.path.join(target,"esky-bootstrap.txt")
+            bsfile_old = os.path.join(target,"esky-bootstrap-old.txt")
         self.lock()
         try:
             if not os.path.exists(target):
@@ -811,7 +846,7 @@ class Esky(object):
                 if is_locked_version_dir(target):
                     raise VersionLockedError("version in use: %s" % (version,))
                 raise
-            #  Disable the version by renaming its esky-bootstrap.txt file.
+            #  Disable the version by renaming its bootstrap-manifest.txt file.
             #  To avoid clobbering in-use version, respect locks on this file.
             if sys.platform == "win32":
                 try:
@@ -869,7 +904,9 @@ class Esky(object):
         This is the set of files/directories that the given version expects
         to be in the main app directory.
         """
-        mpath = os.path.join(self.appdir,vdir,"esky-bootstrap.txt")
+        mpath = os.path.join(self.appdir,vdir,ESKY_CONTROL_DIR,"bootstrap-manifest.txt")
+        if not os.path.exists(mpath):
+            mpath = os.path.join(self.appdir,vdir,"esky-bootstrap.txt")
         manifest = set()
         try:
             with open(mpath,"rt") as mf:
