@@ -32,6 +32,8 @@ use during the bootstrap process:
 import sys
 import errno
 
+ESKY_CONTROL_DIR = "esky-files"
+
 #  The os module is not builtin, so we grab what we can from the
 #  platform-specific modules and fudge the rest.
 if "posix" in sys.builtin_module_names:
@@ -136,8 +138,10 @@ def chainload(target_dir):
         #  If the bootstrap file is missing, the version is being uninstalled.
         #  Our only option is to re-execute ourself and find the new version.
         if exists(dirname(target_dir)):
-            if not exists(pathjoin(target_dir,"esky-bootstrap.txt")):
-                execv(sys.executable,sys.argv)
+            if not exists(pathjoin(target_dir,ESKY_CONTROL_DIR,"bootstrap-manifest.txt")):
+                # TODO: remove compatability hook
+                if not exists(pathjoin(target_dir,"esky-bootstrap.txt")):
+                    execv(sys.executable,sys.argv)
         raise
     else:
         #  If all goes well, we can actually launch the target version.
@@ -146,7 +150,7 @@ def chainload(target_dir):
 
 def get_exe_locations(target_dir):
     """Generate possible locations from which to chainload in the target dir."""
-    appdir = dirname(target_dir)
+    appdir = appdir_from_executable(sys.executable)
     #  If we're in an appdir, first try to launch from within "<appname>.app"
     #  directory.  We must also try the default scheme for backwards compat.
     if sys.platform == "darwin":
@@ -255,27 +259,42 @@ def get_all_versions(appdir,include_partial_installs=False):
 def is_version_dir(vdir):
     """Check whether the given directory contains an esky app version.
 
-    Currently, it only need contain the "esky-bootstrap.txt" file.
+    Currently it only need contain the "esky-files/bootstrap-mainfest.txt" file.
     """
-    return exists(pathjoin(vdir,"esky-bootstrap.txt"))
+    if exists(pathjoin(vdir,ESKY_CONTROL_DIR,"bootstrap-manifest.txt")):
+        return True
+    # TODO: remove compatability hook
+    if exists(pathjoin(vdir,"esky-bootstrap.txt")):
+        return True
+    return False
 
 
 def is_installed_version_dir(vdir):
     """Check whether the given version directory is fully installed.
 
     Currently, a completed installation is indicated by the lack of an
-    "esky-bootstrap" directory.
+    "esky-files/bootstrap" directory.
     """
-    return not exists(pathjoin(vdir,"esky-bootstrap"))
+    # TODO: remove compatability hook
+    if not exists(pathjoin(vdir,ESKY_CONTROL_DIR,"bootstrap")):
+        if not exists(pathjoin(vdir,"esky-bootstrap")):
+            return True
+    return False
 
 
 def is_uninstalled_version_dir(vdir):
     """Check whether the given version directory is partially uninstalled.
 
-    A partially-uninstalled version dir has had its "esky-bootstrap.txt"
-    file renamed to "esky-bootstrap-old.txt".
+    A partially-uninstalled version dir has had the "bootstrap-manifest.txt"
+    renamed to "bootstrap-manifest-old.txt".
     """
-    return exists(pathjoin(vdir,"esky-bootstrap-old.txt"))
+    if exists(pathjoin(vdir,ESKY_CONTROL_DIR,"bootstrap-manifest-old.txt")):
+        return True
+    # TODO: remove compatability hooks
+    if exists(pathjoin(vdir,"esky-bootstrap-old.txt")):
+        return True
+    return False
+    
 
 
 def split_app_version(s):
@@ -394,10 +413,13 @@ def lock_version_dir(vdir):
     if sys.platform == "win32":
         #  On win32, we just hold bootstrap file open for reading.
         #  This will prevent it from being renamed during uninstall.
-        lockfile = pathjoin(vdir,"esky-bootstrap.txt")
+        lockfile = pathjoin(vdir,ESKY_CONTROL_DIR,"bootstrap-manifest.txt")
+        # TODO: remove compatability hooks
+        if not exists(lockfile):
+            lockfile = pathjoin(vdir,"esky-bootstrap.txt")
         _locked_version_dirs.setdefault(vdir,[]).append(open(lockfile,"rt"))
     else:
-        #  On posix platforms we take a shared flock on esky-lockfile.txt.
+        #  On posix platforms we take a shared flock on esky-files/lockfile.txt.
         #  While fcntl.fcntl locks are apparently the new hotness, they have
         #  unfortunate semantics that we don't want for this application:
         #      * not inherited across fork()
@@ -405,7 +427,10 @@ def lock_version_dir(vdir):
         #  fcntl.flock doesn't have these problems, but may fail on NFS.
         #  To complicate matters, python sometimes emulated flock with fcntl!
         #  We therefore use a separate lock file to avoid unpleasantness.
-        lockfile = pathjoin(vdir,"esky-lockfile.txt")
+        lockfile = pathjoin(vdir,ESKY_CONTROL_DIR,"lockfile.txt")
+        # TODO: remove compatability hooks
+        if not exists(lockfile):
+            lockfile = pathjoin(vdir,"esky-lockfile.txt")
         f = open(lockfile,"r")
         _locked_version_dirs.setdefault(vdir,[]).append(f)
         fcntl.flock(f,fcntl.LOCK_SH)
