@@ -9,6 +9,8 @@ import stat
 import esky
 import esky.util
 import esky.tests
+
+ESKY_CONTROL_DIR = esky.util.ESKY_CONTROL_DIR
  
 
 platform = esky.util.get_platform()
@@ -67,7 +69,7 @@ if len(sys.argv) == 1:
     assert not os.path.isdir(v1dir)
     assert not os.path.isdir(v3dir)
     #  Check that the bootstrap env is intact
-    with open(os.path.join(app.appdir,"eskytester-0.2."+platform,"esky-bootstrap.txt"),"rt") as mf:
+    with open(os.path.join(app.appdir,"eskytester-0.2."+platform,ESKY_CONTROL_DIR,"bootstrap-manifest.txt"),"rt") as mf:
         for nm in mf:
             nm = nm.strip()
             assert os.path.exists(os.path.join(app.appdir,nm))
@@ -78,24 +80,24 @@ if len(sys.argv) == 1:
     #  While we're here, check that the bootstrap library hasn't changed
     if os.path.exists(os.path.join(app.appdir,"library.zip")):
         f1 = open(os.path.join(app.appdir,"library.zip"),"rb")
-        f2 = open(os.path.join(v3dir,"esky-bootstrap","library.zip"),"rb")
+        f2 = open(os.path.join(v3dir,ESKY_CONTROL_DIR,"bootstrap","library.zip"),"rb")
         assert f1.read() == f2.read()
         f1.close()
         f2.close()
     #  Also check one of the bootstrap exes to make sure it has changed safely
     if sys.platform == "win32":
         f1 = open(os.path.join(app.appdir,"script2"+dotexe),"rb")
-        f2 = open(os.path.join(v3dir,"esky-bootstrap","script2"+dotexe),"rb")
+        f2 = open(os.path.join(v3dir,ESKY_CONTROL_DIR,"bootstrap","script2"+dotexe),"rb")
         if f1.read() != f2.read():
             assert esky.winres.is_safe_to_overwrite(f1.name,f2.name), "bootstrap exe was changed unsafely"
         f1.close()
         f2.close()
     if sys.platform == "darwin":
-        os.unlink(os.path.join(v3dir,"esky-bootstrap/Contents/MacOS/script2"))
+        os.unlink(os.path.join(v3dir,ESKY_CONTROL_DIR,"bootstrap/Contents/MacOS/script2"))
     elif sys.platform != "win32":
         # win32 won't let us delete it since we loaded it as a library
         # when checking whether it was safe to overwrite.
-        os.unlink(os.path.join(v3dir,"esky-bootstrap","script2"+dotexe))
+        os.unlink(os.path.join(v3dir,ESKY_CONTROL_DIR,"bootstrap","script2"+dotexe))
     #  Re-launch the script.
     #  We should still be at version 0.2 after this.
     os.execv(script2,[script2,"rerun"])
